﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 라인 1 시리즈
        /// </summary>
        private Line line1;

        /// <summary>
        /// 제곱 평균 제곱근 함수
        /// </summary>
        private RootMeanSquare rootMeanSquare;

        /// <summary>
        /// 라인 2 시리즈
        /// </summary>
        private Line line2;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 라인 1 시리즈를 생성한다.

            this.line1 = new Line();

            this.line1.Title = "Data";
            this.line1.Color = Color.FromArgb(68, 102, 163);

            #endregion
            #region 제곱 평균 제곱근 함수를 생성한다.

            this.rootMeanSquare = new RootMeanSquare();

            #endregion
            #region 라인 2 시리즈를 생성한다.

            this.line2 = new Line();

            this.line2.Title                 = "RMS";
            this.line2.Color                 = Color.FromArgb(243, 156, 53);
            this.line2.Pointer.Brush.Color   = Color.FromArgb(255, 255, 255);
            this.line2.Pointer.Brush.Visible = true;
            this.line2.Pointer.Visible       = true;
            this.line2.DataSource            = this.line1;
            this.line2.Function              = this.rootMeanSquare;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Series.Add(this.line1);
            this.tChart.Series.Add(this.line2);

            #endregion

            this.line1.FillSampleValues(30);

            Load                                    += Form_Load;
            this.styleComboBox.SelectedIndexChanged += styleComboBox_SelectedIndexChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.styleComboBox.SelectedIndex = 0;
        }

        #endregion
        #region 스타일 콤보 박스 선택 인덱스 변경시 처리하기 - styleComboBox_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 스타일 콤보 박스 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void styleComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.rootMeanSquare.Complete = (this.styleComboBox.SelectedIndex == 1);

            this.rmsValueLabel.Text = this.line2.YValues[0].ToString("0.00");
        }

        #endregion
    }
}